@@ -1,5 +1,4 @@
 package RDF::Generator::Void::Stats;
-use Progress::Any;
 
 use 5.006;
 use strict;
@@ -47,13 +46,6 @@ The number of distinct subjects, as defined in the specification.
 
 The number of distinct objects, as defined in the specification.
 
-=head3 C<propertyPartitions>
-
-A hashref containing the number of triples for each property.
-
-=head3 C<classPartitions>
-
-A hashref containing the number of triples for each class.
 
 
 =cut
@@ -61,11 +53,13 @@ A hashref containing the number of triples for each class.
 # The following attributes also act as read-write methods.
 has vocabularies => ( is => 'rw', isa => 'HashRef' );
 
-has ['entities', 'properties', 'subjects', 'objects'] => ( is => 'rw', isa => 'Int' );
+has entities => ( is => 'rw', isa => 'Int' );
 
-has propertyPartitions => (is => 'rw', isa => 'HashRef' );
+has properties => ( is => 'rw', isa => 'Int' );
 
-has classPartitions => (is => 'rw', isa => 'HashRef' );
+has subjects => ( is => 'rw', isa => 'Int' );
+
+has objects => ( is => 'rw', isa => 'Int' );
 
 # This is a read-only method, meaning that the constructor has it as a
 # parameter, but then it can only be read from.
@@ -81,11 +75,9 @@ sub BUILD {
 	my ($self) = @_;
 
 	# Initialize local hashes to count stuff.
-	my (%vocab_counter, %entities, %properties, %subjects, %objects, %classes);
-	my $progress = Progress::Any->get_indicator(task => "compute");
- 
-	my $gen = $self->generator;
+	my (%vocab_counter, %entities, %properties, %subjects, %objects);
 
+	my $gen = $self->generator;
 	# Here, we take the data in the model we want to generate
 	# statistics for and we iterate over it. Doing it this way, we
 	# should be able to generate all statistics in a single pass of the
@@ -101,9 +93,7 @@ sub BUILD {
 			$vocab_counter{$vocab_uri}++;
 		};
 
-		
-
-		if ($gen->has_urispace && $st->subject->is_resource) {
+		if ($gen->has_urispace) {
 			# Compute entities. We assume that all entities are subjects
 			# with a prefix matching the uriSpace. Again, we use the
 			# property that keys are unique, but we just set it to some
@@ -113,36 +103,18 @@ sub BUILD {
 			$entities{$st->subject->uri_value} = 1 if ($st->subject->uri_value =~ m/^$urispace/);
 		}
 		
-		$subjects{$st->subject->sse} = 1;
-		$properties{$st->predicate->uri_value}{'triples'}++;
+		$subjects{$st->subject->uri_value} = 1;
+		$properties{$st->predicate->uri_value} = 1;
 		$objects{$st->object->sse} = 1;
-
-		if ((!$gen->has_level) || ($gen->has_level && $gen->level >= 1)) {
-			if (($st->predicate->uri_value eq 'http://www.w3.org/1999/02/22-rdf-syntax-ns#type')
-				 && $st->object->is_resource) {
-				$classes{$st->object->uri_value}++
-			}
-		}
-
-		if ((!$gen->has_level) || ($gen->has_level && $gen->level > 2)) {
-			$properties{$st->predicate->uri_value}{'countsubjects'}{$st->subject->sse} = 1;
-			$properties{$st->predicate->uri_value}{'countobjects'}{$st->object->sse} = 1;
-		}
-		$progress->update(message => "Examening triples");
 	});
 
-
 	# Finally, we update the attributes above, they are returned as a side-effect
 	$self->vocabularies(\%vocab_counter);
 	$self->entities(scalar keys %entities);
 	$self->properties(scalar keys %properties);
 	$self->subjects(scalar keys %subjects);
 	$self->objects(scalar keys %objects);
-	if ((!$gen->has_level) || ($gen->has_level && $gen->level >= 1)) {
-		$self->propertyPartitions(\%properties);
-		$self->classPartitions(\%classes);
-	}
-	$progress->update(message => "Data transfer");
+	
 }
 
 =head1 FURTHER DOCUMENTATION
